@@ -1,4 +1,9 @@
 package POE::Component::Client::NRPE;
+{
+  $POE::Component::Client::NRPE::VERSION = '0.20';
+}
+
+#ABSTRACT: A POE Component that implements check_nrpe functionality
 
 use strict;
 use warnings;
@@ -8,9 +13,6 @@ use POE::Component::SSLify qw( Client_SSLify );
 use Carp;
 use Socket;
 use integer;
-use vars qw($VERSION);
-
-$VERSION = '0.18';
 
 sub check_nrpe {
   my $package = shift;
@@ -297,11 +299,18 @@ sub _crc32 {
 }
 
 'POE it';
+
 __END__
 
+=pod
+
 =head1 NAME
 
-POE::Component::Client::NRPE - a POE Component that implements check_nrpe functionality
+POE::Component::Client::NRPE - A POE Component that implements check_nrpe functionality
+
+=head1 VERSION
+
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -350,9 +359,13 @@ POE::Component::Client::NRPE - a POE Component that implements check_nrpe functi
 =head1 DESCRIPTION
 
 POE::Component::Client::NRPE is a L<POE> component that implements version 1 and version 2 of
-the nrpe (Nagios Remote Plugin Executor) client, check_nrpe. It also supports SSL encryption 
+the nrpe (Nagios Remote Plugin Executor) client, check_nrpe. It also supports SSL encryption
 using L<Net::SSLeay> and a hacked version of L<POE::Component::SSLify>.
 
+=head1 NAME
+
+POE::Component::Client::NRPE - a POE Component that implements check_nrpe functionality
+
 =head1 CONSTRUCTOR
 
 =over
@@ -389,21 +402,13 @@ This is generated by the poco. ARG0 will be a hash reference with the following
   'command', the command that was run;
   'context', anything that you specified;
   'result', the Nagios result code, can be 0,1,2 or 3;
-  'data', what the NRPEd gave us by way of output; 
+  'data', what the NRPEd gave us by way of output;
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+=head1 ACKNOWLEDGEMENTS
 
 This module uses code derived from L<http://www.stic-online.de/stic/html/nrpe-generic.html>
 Copyright (C) 2006, 2007 STIC GmbH, http://www.stic-online.de
 
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams, Apocalypse, Rocco Caputo and STIC GmbH.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE>
@@ -411,3 +416,16 @@ L<POE>
 L<POE::Component::SSLify>
 
 L<http://www.nagios.org/>
+
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Chris Williams, Apocalypse, Rocco Caputo and STIC GmbH..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
